{ config, pkgs, lib, inputs, ... }:
{
  imports = [ 
    ./firefox.nix
    ./ssh.nix
  ];

  home.username = "kb";
  home.homeDirectory = "/home/kb";
  home.packages = with pkgs; [
    # System
    kdePackages.kate
    kdePackages.kcalc
    # Office
    thunderbird
    libreoffice-qt6-fresh
    logseq
    kdePackages.itinerary
    ungoogled-chromium
    # Security
    gnupg
    keepassxc
    pass-wayland
    veracrypt
    protonvpn-gui
    # Media
    freetube
    inkscape
    blender
    obs-studio
    cheese
    gimp
    vlc
    kid3
    #calibre
    spotify-player
    tidal-hifi
    # Messengers
    element-desktop # Matrix Client
    signal-desktop
    deltachat-desktop
    webcord
    # Customization
    razergenie
    firefoxpwa
    # Development
    vscodium
    scrcpy
    # Experiments
    yazi # Terminal File-Manager
    # Gaming
    ryujinx # Experimental Nitendo Switch Emulator
    mangohud
    prismlauncher
    kb-one.olympus
    gnome-sudoku
    # Terminal Tools
    mosh
    btop
    fastfetch
  ];

  services.syncthing.enable = true;
  services.syncthing.extraOptions = [
    "--config=/home/kb/.config/syncthing"
    "--data=/home/kb/sync"
  ];

  services.kdeconnect.enable = true;
  services.safeeyes.enable = true;

  services.gpg-agent.enable = true;

  programs.vim.enable = true;
  programs.vim.defaultEditor = true;
  programs.helix.enable = true;

  home.stateVersion = "24.05";
}
