{ config, lib, pkgs, ... }:

{
  imports = [
    ./hardware.nix
  ];

  # Configure Nix
  nix.package = pkgs.lix;
  nix.settings = {
    experimental-features = [ "nix-command" "flakes" ];
  };
  nixpkgs.config.allowUnfree = true;
  nixpkgs.config.permittedInsecurePackages = [
    "electron-27.3.11"
    "olm-3.2.16"
  ];

  # Distributed Builds
  nix.buildMachines = [
    {
      hostName = "kb-senfnvp-remotebuild";
      systems = [ "aarch64-linux" ];
      protocol = "ssh-ng";
      maxJobs = 10;
      speedFactor = 2;
      supportedFeatures = [ "nixos-test" "benchmark" "big-parallel" ];
      mandatoryFeatures = [];
    }
  ];
  nix.distributedBuilds = true;
  nix.extraOptions = ''
    builders-use-substitutes = true
  '';

  # NAS Test-Config
  suites.nas.enable = false;
  
  # Networking
  networking.hostName = "Ohybke";
  networking.networkmanager.enable = true;
  #networking.wireless.enable = true;
  # Allow KDE Connect Ports
  networking.firewall.allowedTCPPortRanges = [{ from = 1714; to = 1764; }];
  networking.firewall.allowedUDPPortRanges = [{ from = 1714; to = 1764; }];
  # Allow VLC Chromecast
  networking.firewall.allowedTCPPorts = [ 8010 ];

  # Enable Bluetooth
  hardware.bluetooth.enable = true;
  hardware.bluetooth.powerOnBoot = true;

  # Locale
  time.timeZone = "Europe/Berlin";
  i18n.defaultLocale = "en_US.UTF-8";
  i18n.extraLocaleSettings = {
    LC_ADDRESS = "de_DE.UTF-8";
    LC_IDENTIFICATION = "de_DE.UTF-8";
    LC_MEASUREMENT = "de_DE.UTF-8";
    LC_MONETARY = "de_DE.UTF-8";
    LC_NAME = "de_DE.UTF-8";
    LC_NUMERIC = "de_DE.UTF-8";
    LC_PAPER = "de_DE.UTF-8";
    LC_TELEPHONE = "de_DE.UTF-8";
    LC_TIME = "de_DE.UTF-8";
  };

  # Enable the X11 windowing system.
  services.xserver.enable = true;

  # Enable the KDE Plasma Desktop Environment.
  services.displayManager.sddm.enable = true;
  services.desktopManager.plasma6.enable = true;

  # Keyboard and Keymap
  services.xserver.xkb = {
    layout = "de";
    variant = "mac_nodeadkeys";
    options = "";
  };
  console = {
    font = "Lat2-Terminus16";
    # keyMap = "de";
    useXkbConfig = true;
  };

  # Enable CUPS to print documents.
  services.printing.enable = true;

  # Enable sound with pipewire.
  services.pulseaudio.enable = false;
  security.rtkit.enable = true;
  services.pipewire = {
    enable = true;
    alsa.enable = true;
    alsa.support32Bit = true;
    pulse.enable = true;
  };

  # Protonmail Bridge
  services.protonmail-bridge.enable = true;

  # Languagetool Spellchecking Server  
  services.languagetool = {
    enable = true;
    allowOrigin = "*";
  };

  # Enable Avahi Daemon for Chromecast
  services.avahi.enable = true;

  # Users
  users.users.kb = { # Managed by Homemanager
    isNormalUser = true;
    description = "kB";
    extraGroups = [ "networkmanager" "wheel" ];
  };

  # Enable SSH-Agent
  programs.ssh.startAgent = true;

  # Enable Steam
  programs.steam.enable = true;

  # Packages installed in system profile. Search Packages: $ nix search wget
  environment.systemPackages = with pkgs; [
    vim
    helix
    git
    tree
    dmg2img
    curl
    python3
    sops
    kb-one.numen
    kb-one.dotool
    kb-one.vosk-model-small-en-us
  ];

  system.stateVersion = "24.11"; # NEVER Change this!

}

